@@ -1,6 +1,6 @@
 /* FSNIconsView.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -28,6 +28,7 @@
 
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
+#import <GNUstepGUI/GSVersion.h>
 
 #import "FSNIconsView.h"
 #import "FSNIcon.h"
@@ -63,6 +64,27 @@ if (rct.size.height < 0) rct.size.height = 0; \
 [o setFrame: NSIntegralRect(rct)]; \
 }
 
+/* we redefine the dockstyle to read the preferences without including Dock.h" */
+typedef enum DockStyle
+{   
+  DockStyleClassic = 0,
+  DockStyleModern = 1
+} DockStyle;
+
+#define SUPPORTS_XOR ((GNUSTEP_GUI_MAJOR_VERSION > 0)		\
+		      || (GNUSTEP_GUI_MAJOR_VERSION == 0	\
+			  && GNUSTEP_GUI_MINOR_VERSION > 22)	\
+		      || (GNUSTEP_GUI_MAJOR_VERSION == 0	\
+			  && GNUSTEP_GUI_MINOR_VERSION == 22	\
+			  && GNUSTEP_GUI_SUBMINOR_VERSION > 0))
+
+static void GWHighlightFrameRect(NSRect aRect)
+{
+#if SUPPORTS_XOR
+  NSFrameRectWithWidthUsingOperation(aRect, 1.0, GSCompositeHighlight);
+#endif
+}
+
 
 @implementation FSNIconsView
 
@@ -97,11 +119,17 @@ if (rct.size.height < 0) rct.size.height = 0; \
     fsnodeRep = [FSNodeRep sharedInstance];
     
     if (appName && selName) {
-		  Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
+      Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
       SEL sel = NSSelectorFromString(selName);
       desktopApp = [desktopAppClass performSelector: sel];
     }
-  
+
+    /* we tie the transparent selection to the modern dock style */
+    transparentSelection = NO;
+    defentry = [defaults objectForKey: @"dockstyle"];
+    if ([defentry intValue] == DockStyleModern)
+      transparentSelection = YES;
+
     ASSIGN (backColor, [NSColor windowBackgroundColor]);
     ASSIGN (textColor, [NSColor controlTextColor]);
     ASSIGN (disabledTextColor, [NSColor disabledControlTextColor]);
@@ -140,11 +168,11 @@ if (rct.size.height < 0) rct.size.height = 0; \
         
     nameEditor = [FSNIconNameEditor new];
     [nameEditor setDelegate: self];  
-		[nameEditor setFont: labelFont];
-		[nameEditor setBezeled: NO];
-		[nameEditor setAlignment: NSCenterTextAlignment];
-	  [nameEditor setBackgroundColor: backColor];
-	  [nameEditor setTextColor: textColor];
+    [nameEditor setFont: labelFont];
+    [nameEditor setBezeled: NO];
+    [nameEditor setAlignment: NSCenterTextAlignment];
+    [nameEditor setBackgroundColor: backColor];
+    [nameEditor setTextColor: textColor];
     [nameEditor setEditable: NO];
     [nameEditor setSelectable: NO];
     editIcon = nil;
@@ -444,11 +472,11 @@ if (rct.size.height < 0) rct.size.height = 0; \
 {
   unsigned int eventMask = NSLeftMouseUpMask | NSLeftMouseDraggedMask | NSPeriodicMask;
   NSDate *future = [NSDate distantFuture];
-  NSPoint	startp, sp;
+  NSPoint	sp;
   NSPoint	p, pp;
   NSRect visibleRect;
   NSRect oldRect; 
-  NSRect r, wr;
+  NSRect r;
   NSRect selrect;
   float x, y, w, h;
   int i;
@@ -479,16 +507,16 @@ pp.y = NSMaxY(br) + 1; \
 
   p = [theEvent locationInWindow];
   sp = [self convertPoint: p  fromView: nil];
-  startp = [self convertPoint: p fromView: nil];
   
   oldRect = NSZeroRect;  
 
-	[[self window] disableFlushWindow];
-  [self lockFocus];
+  [[self window] disableFlushWindow];
 
   [NSEvent startPeriodicEventsAfterDelay: 0.02 withPeriod: 0.05];
 
   while ([theEvent type] != NSLeftMouseUp) {
+    BOOL scrolled = NO;
+
     CREATE_AUTORELEASE_POOL (arp);
 
     theEvent = [NSApp nextEventMatchingMask: eventMask
@@ -504,82 +532,60 @@ pp.y = NSMaxY(br) + 1; \
     
     visibleRect = [self visibleRect];
     
-    if ([self mouse: pp inRect: visibleRect] == NO) {
-      scrollPointToVisible(pp);
-      CONVERT_CHECK;
-      visibleRect = [self visibleRect];
-    }
+    if ([self mouse: pp inRect: visibleRect] == NO)
+      {
+	scrollPointToVisible(pp);
+	CONVERT_CHECK;
+	visibleRect = [self visibleRect];
 
-    if ((sp.y < visibleRect.origin.y)
-          || (sp.y > (visibleRect.origin.y + visibleRect.size.height))) {
-      if (sp.y < visibleRect.origin.y) {
-        sp.y = visibleRect.origin.y - 1;
+	scrolled = YES;
       }
-      if (sp.y > (visibleRect.origin.y + visibleRect.size.height)) {
-        sp.y = (visibleRect.origin.y + visibleRect.size.height + 1);
-      }
-    } 
 
-    x = (pp.x >= sp.x) ? sp.x : pp.x;
-    y = (pp.y >= sp.y) ? sp.y : pp.y;
-    w = max(pp.x, sp.x) - min(pp.x, sp.x);
-    w = (w == 0) ? 1 : w;
-    h = max(pp.y, sp.y) - min(pp.y, sp.y);
-    h = (h == 0) ? 1 : h;
+    x = min(sp.x, pp.x);
+    y = min(sp.y, pp.y);
+    w = max(1, max(pp.x, sp.x) - min(pp.x, sp.x));
+    h = max(1, max(pp.y, sp.y) - min(pp.y, sp.y));
 
     r = NSMakeRect(x, y, w, h);
     
-    if (NSEqualRects(visibleRect, [self frame])) {
-      r = NSIntersectionRect(r, visibleRect);
-    }
-    
-    wr = [self convertRect: r toView: nil];
-  
-    sp = startp;
+    // Erase the previous rect
+    if (transparentSelection
+	|| !SUPPORTS_XOR
+	|| (!transparentSelection && scrolled))
+      {
+	[self setNeedsDisplayInRect: oldRect];
+	[[self window] displayIfNeeded];
+      }
+ 
+    // Draw the new rect
 
-    if (NSEqualRects(oldRect, NSZeroRect) == NO) {
-		  [verticalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                         fromRect: NSMakeRect(0.0, 0.0, 1.0, oldRect.size.height)
-		                        operation: NSCompositeCopy];
+    [self lockFocus];
 
-		  [verticalImage compositeToPoint: NSMakePoint(NSMaxX(oldRect)-1, NSMinY(oldRect))
-		                         fromRect: NSMakeRect(1.0, 0.0, 1.0, oldRect.size.height)
-		                        operation: NSCompositeCopy];
+    if (transparentSelection || !SUPPORTS_XOR)
+      {
+	[[NSColor darkGrayColor] set];
+	NSFrameRect(r);
+	if (transparentSelection)
+	  {
+	    [[[NSColor darkGrayColor] colorWithAlphaComponent: 0.33] set];
+	    NSRectFillUsingOperation(r, NSCompositeSourceOver);
+	  }
+      }
+    else
+      {
+	if (!NSEqualRects(oldRect, r) && !scrolled)
+	  {
+	    GWHighlightFrameRect(oldRect);
+	    GWHighlightFrameRect(r);
+	  }
+	else if (scrolled)
+	  {
+	    GWHighlightFrameRect(r);
+	  }
+      }
+     
+    [self unlockFocus];
 
-		  [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                           fromRect: NSMakeRect(0.0, 0.0, oldRect.size.width, 1.0)
-		                          operation: NSCompositeCopy];
-
-      [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMaxY(oldRect)-1)
-		                           fromRect: NSMakeRect(0.0, 1.0, oldRect.size.width, 1.0)
-		                          operation: NSCompositeCopy];
-    }
-    [self displayIfNeeded];
-
-    [verticalImage lockFocus];
-    NSCopyBits([[self window] gState], 
-            NSMakeRect(NSMinX(wr), NSMinY(wr), 
-                          1.0, r.size.height),
-			                          NSMakePoint(0.0, 0.0));
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMaxX(wr) -1, NSMinY(wr),
-				                  1.0, r.size.height),
-			                          NSMakePoint(1.0, 0.0));
-    [verticalImage unlockFocus];
-
-    [horizontalImage lockFocus];
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMinX(wr), NSMinY(wr),
-				                  r.size.width, 1.0),
-			                          NSMakePoint(0.0, 0.0));
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMinX(wr), NSMaxY(wr) -1,
-				                  r.size.width, 1.0),
-			                          NSMakePoint(0.0, 1.0));
-    [horizontalImage unlockFocus];
-
-    [[NSColor darkGrayColor] set];
-    NSFrameRect(r);
     oldRect = r;
 
     [[self window] enableFlushWindow];
@@ -591,38 +597,22 @@ pp.y = NSMaxY(br) + 1; \
   
   [NSEvent stopPeriodicEvents];
   [[self window] postEvent: theEvent atStart: NO];
-  
-  if (NSEqualRects(oldRect, NSZeroRect) == NO) {
-		[verticalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                       fromRect: NSMakeRect(0.0, 0.0, 1.0, oldRect.size.height)
-		                      operation: NSCompositeCopy];
 
-		[verticalImage compositeToPoint: NSMakePoint(NSMaxX(oldRect)-1, NSMinY(oldRect))
-		                       fromRect: NSMakeRect(1.0, 0.0, 1.0, oldRect.size.height)
-		                      operation: NSCompositeCopy];
+  // Erase the previous rect
 
-		[horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                         fromRect: NSMakeRect(0.0, 0.0, oldRect.size.width, 1.0)
-		                        operation: NSCompositeCopy];
-
-    [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMaxY(oldRect)-1)
-		                         fromRect: NSMakeRect(0.0, 1.0, oldRect.size.width, 1.0)
-		                        operation: NSCompositeCopy];
-  }
+  [self setNeedsDisplayInRect: oldRect];
+  [[self window] displayIfNeeded];
   
   [[self window] enableFlushWindow];
   [[self window] flushWindow];
-  [self unlockFocus];
 
   selectionMask = FSNMultipleSelectionMask;
   selectionMask |= FSNCreatingSelectionMask;
 
-  x = (pp.x >= startp.x) ? startp.x : pp.x;
-  y = (pp.y >= startp.y) ? startp.y : pp.y;
-  w = max(pp.x, startp.x) - min(pp.x, startp.x);
-  w = (w == 0) ? 1 : w;
-  h = max(pp.y, startp.y) - min(pp.y, startp.y);
-  h = (h == 0) ? 1 : h;
+  x = min(sp.x, pp.x);
+  y = min(sp.y, pp.y);
+  w = max(1, max(pp.x, sp.x) - min(pp.x, sp.x));
+  h = max(1, max(pp.y, sp.y) - min(pp.y, sp.y));
 
   selrect = NSMakeRect(x, y, w, h);
   
@@ -642,18 +632,18 @@ pp.y = NSMaxY(br) + 1; \
 
 - (void)keyDown:(NSEvent *)theEvent 
 {
-  NSString *characters = [theEvent characters];  
-  unichar character = 0;
-	NSRect vRect, hiddRect;
-	NSPoint p;
-	float x, y, w, h;
+  NSString *characters;  
+  unichar character;
+  NSRect vRect, hiddRect;
+  NSPoint p;
+  float x, y, w, h;
 
-	characters = [theEvent characters];
-	character = 0;
+  characters = [theEvent characters];
+  character = 0;
 		
-  if ([characters length] > 0) {
-		character = [characters characterAtIndex: 0];
-	}
+  if ([characters length] > 0)
+    character = [characters characterAtIndex: 0];
+
 	
   switch (character) {
     case NSPageUpFunctionKey:
