@@ -1,6 +1,6 @@
 /* FSNListView.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: December 2004
@@ -220,26 +220,28 @@ static NSString *defaultColumns = @"{ \
   NSArray *columns = [listView tableColumns];
   NSMutableDictionary *colsinfo = [NSMutableDictionary dictionary];
   
-  if (columns) { 
-    int i;
+  if (columns)
+    { 
+      int i;
 
-    for (i = 0; i < [columns count]; i++) {
-      NSTableColumn *column = [columns objectAtIndex: i];
-      NSNumber *identifier = [column identifier];
-      NSMutableDictionary *dict = [NSMutableDictionary dictionary];
+      for (i = 0; i < [columns count]; i++)
+	{
+	  NSTableColumn *column = [columns objectAtIndex: i];
+	  NSNumber *identifier = [column identifier];
+	  NSMutableDictionary *dict = [NSMutableDictionary dictionary];
 
-      [dict setObject: [NSNumber numberWithInt: i] 
-               forKey: @"position"];
-      [dict setObject: identifier 
-               forKey: @"identifier"];
-      [dict setObject: [NSNumber numberWithFloat: [column width]] 
-               forKey: @"width"];
-      [dict setObject: [NSNumber numberWithFloat: [column minWidth]] 
-               forKey: @"minwidth"];
+	  [dict setObject: [NSNumber numberWithInt: i] 
+		   forKey: @"position"];
+	  [dict setObject: identifier 
+		   forKey: @"identifier"];
+	  [dict setObject: [NSNumber numberWithFloat: [column width]] 
+		   forKey: @"width"];
+	  [dict setObject: [NSNumber numberWithFloat: [column minWidth]] 
+		   forKey: @"minwidth"];
 
-      [colsinfo setObject: dict forKey: identifier];
+	  [colsinfo setObject: dict forKey: [identifier stringValue]];
+	}
     }
-  }
    
   return colsinfo;
 }
@@ -534,7 +536,7 @@ static NSString *defaultColumns = @"{ \
     
     if ([selected count]) {
       id rep = [selected objectAtIndex: 0];
-      int index = [nodeReps indexOfObjectIdenticalTo: rep];
+      NSUInteger index = [nodeReps indexOfObjectIdenticalTo: rep];
       
       [self selectReps: selected];
       
@@ -1160,7 +1162,7 @@ static NSString *defaultColumns = @"{ \
 
   for (i = 0; i < [reps count]; i++) {
     FSNListViewNodeRep *rep = [reps objectAtIndex: i];
-    unsigned int index = [nodeReps indexOfObjectIdenticalTo: rep];
+    NSUInteger index = [nodeReps indexOfObjectIdenticalTo: rep];
   
     if (index != NSNotFound) {
       [set addIndex: index];
@@ -1217,7 +1219,7 @@ static NSString *defaultColumns = @"{ \
 - (void)selectAll
 {
   NSMutableIndexSet *set = [NSMutableIndexSet indexSet];
-  unsigned int i;
+  NSUInteger i;
 
   for (i = 0; i < [nodeReps count]; i++) {
     FSNListViewNodeRep *rep = [nodeReps objectAtIndex: i];
@@ -1254,68 +1256,43 @@ static NSString *defaultColumns = @"{ \
 
 - (NSArray *)selectedReps
 {
-  CREATE_AUTORELEASE_POOL (pool);
   NSIndexSet *set = [listView selectedRowIndexes];
-  int count = [set count];
-  NSRange range = NSMakeRange(0, NSNotFound -1);
-  unsigned int *buf = NSZoneMalloc (NSDefaultMallocZone(), sizeof(unsigned int) * count);
-  int selcount = [set getIndexes: buf maxCount: count inIndexRange: &range];
   NSMutableArray *selreps = [NSMutableArray array];
-  int i;
 
-  for (i = 0; i < selcount; i++) {
-    [selreps addObject: [nodeReps objectAtIndex: buf[i]]];
-  }
-
-	NSZoneFree (NSDefaultMallocZone(), buf);
-  RETAIN (selreps);
-  RELEASE (pool);
-
-  return [[selreps autorelease] makeImmutableCopyOnFail: NO];
+  NSUInteger i;
+  for (i = [set firstIndex]; i != NSNotFound; i = [set indexGreaterThanIndex: i])
+    {
+      [selreps addObject: [nodeReps objectAtIndex: i]];
+    }
+  return [NSArray arrayWithArray: selreps];
 }
 
 - (NSArray *)selectedNodes
 {
-  CREATE_AUTORELEASE_POOL (pool);
-  NSIndexSet *set = [listView selectedRowIndexes];
-  int count = [set count];
-  NSRange range = NSMakeRange(0, NSNotFound -1);
-  unsigned int *buf = NSZoneMalloc (NSDefaultMallocZone(), sizeof(unsigned int) * count);
-  int selcount = [set getIndexes: buf maxCount: count inIndexRange: &range];
   NSMutableArray *selnodes = [NSMutableArray array];
-  int i;
 
-  for (i = 0; i < selcount; i++) {
-    [selnodes addObject: [[nodeReps objectAtIndex: buf[i]] node]];
-  }
+  NSEnumerator *e = [[self selectedReps] objectEnumerator];
+  id rep;
+  while ((rep = [e nextObject]) != nil)
+    {
+      [selnodes addObject: [rep node]];
+    }
 
-	NSZoneFree (NSDefaultMallocZone(), buf);
-  RETAIN (selnodes);
-  RELEASE (pool);
-
-  return [[selnodes autorelease] makeImmutableCopyOnFail: NO];
+  return [NSArray arrayWithArray: selnodes];
 }
 
 - (NSArray *)selectedPaths
 {
-  CREATE_AUTORELEASE_POOL (pool);
-  NSIndexSet *set = [listView selectedRowIndexes];
-  int count = [set count];
-  NSRange range = NSMakeRange(0, NSNotFound -1);
-  unsigned int *buf = NSZoneMalloc (NSDefaultMallocZone(), sizeof(unsigned int) * count);
-  int selcount = [set getIndexes: buf maxCount: count inIndexRange: &range];
   NSMutableArray *selpaths = [NSMutableArray array];
-  int i;
 
-  for (i = 0; i < selcount; i++) {
-    [selpaths addObject: [[[nodeReps objectAtIndex: buf[i]] node] path]];
-  }
+  NSEnumerator *e = [[self selectedNodes] objectEnumerator];
+  id n;
+  while ((n = [e nextObject]) != nil)
+    {
+      [selpaths addObject: [n path]];
+    }
 
-	NSZoneFree (NSDefaultMallocZone(), buf);
-  RETAIN (selpaths);
-  RELEASE (pool);
-
-  return [[selpaths autorelease] makeImmutableCopyOnFail: NO];
+  return [NSArray arrayWithArray: selpaths];
 }
 
 - (void)selectionDidChange
@@ -1414,7 +1391,7 @@ static NSString *defaultColumns = @"{ \
 
 @implementation FSNListViewDataSource (RepNameEditing)
 
-- (void)setEditorAtRow:(int)row
+- (void)setEditorAtRow:(int)row withMouseDownEvent: (NSEvent *)anEvent
 {
   [self stopRepNameEditing];
 
@@ -1442,6 +1419,11 @@ static NSString *defaultColumns = @"{ \
       [nameEditor setNode: nd stringValue: [nd name] index: 0];
 
       [listView addSubview: nameEditor];
+
+      if (anEvent != nil)
+	{
+	  [nameEditor mouseDown: anEvent];
+	}
     }
   }
 }
@@ -2496,35 +2478,59 @@ int sortSubviews(id view1, id view2, void *context)
   }
 }
 
-- (void)mouseDown:(NSEvent *)theEvent
+- (void)singleClick: (NSTimer *)aTimer
 {
+  NSEvent *theEvent = [aTimer userInfo];
   NSPoint location;
-  int clickCount;
   int row;
-  
-  [dsource setMouseFlags: [theEvent modifierFlags]];
-    
-  [dsource stopRepNameEditing];
-  
-  [super mouseDown: theEvent];
-  
-  clickCount = [theEvent clickCount];
-  
-  if (clickCount >= 2) {
-    return;
-  }
 
-  if ([theEvent modifierFlags] & NSShiftKeyMask) {
-    return;
-  }
-  
   location = [theEvent locationInWindow];
   location = [self convertPoint: location fromView: nil];
   row = [self rowAtPoint: location];
   
   if (row != -1) {  
-    [dsource setEditorAtRow: row];
+    [dsource setEditorAtRow: row withMouseDownEvent: theEvent];
   }
+  
+  [clickTimer release];
+  clickTimer = nil;
+}
+
+- (void)mouseDown:(NSEvent *)theEvent
+{
+  if (clickTimer != nil)
+    {
+      [clickTimer invalidate];
+      [clickTimer release];
+      clickTimer = nil;
+    }
+  
+  if ([theEvent clickCount] == 1
+      && (!([theEvent modifierFlags] & NSShiftKeyMask)))
+    {
+       NSPoint location;
+       int row;
+       
+       location = [theEvent locationInWindow];
+       location = [self convertPoint: location fromView: nil];
+       row = [self rowAtPoint: location];
+       
+       if (row == [self selectedRow])
+	 {
+	   // We clicked on an already-selected row.
+
+	   ASSIGN(clickTimer, [NSTimer scheduledTimerWithTimeInterval: 0.5 // FIXME: use [NSEvent doubleClickInterval]
+							       target: self
+							     selector: @selector(singleClick:)
+							     userInfo: theEvent
+							      repeats: NO]);
+	 }
+    }
+
+  [dsource setMouseFlags: [theEvent modifierFlags]];   
+  [dsource stopRepNameEditing];
+  
+  [super mouseDown: theEvent];
 }
 
 - (void)keyDown:(NSEvent *)theEvent
