@@ -1,8 +1,9 @@
 /* FSNodeRep.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -31,7 +32,21 @@
 #import "ExtendedInfo.h"
 #import "config.h"
 
-#ifndef __APPLE__
+
+#ifdef HAVE_GETMNTINFO
+  #include <sys/param.h>
+  #include <sys/ucred.h>
+  #include <sys/mount.h>
+#ifdef HAVE_SYS_TYPES_H
+  #include <sys/types.h>
+#ifdef HAVE_SYS_STATVFS_H
+  #include <sys/statvfs.h>
+  #ifdef __NetBSD__
+    #define statfs statvfs
+  #endif
+#endif
+#endif /* HAVE_SYSTYPES */
+#else 
   #if	defined(HAVE_GETMNTENT) && defined (MNT_DIR)
     #if	defined(HAVE_MNTENT_H)
       #include <mntent.h>
@@ -41,12 +56,6 @@
       #undef HAVE_GETMNTENT
     #endif
   #endif
-#else
-  #ifdef HAVE_GETMNTINFO
-    #include <sys/param.h>
-    #include <sys/ucred.h>
-    #include <sys/mount.h>
-  #endif  
 #endif
 
 #define LABEL_W_FACT (8.0)
@@ -61,7 +70,7 @@ static FSNodeRep *shared = nil;
 - (void)loadExtendedInfoModules;
 
 - (NSArray *)bundlesWithExtension:(NSString *)extension 
-												   inPath:(NSString *)path;
+			   inPath:(NSString *)path;
 
 @end
 
@@ -201,7 +210,7 @@ static FSNodeRep *shared = nil;
 }
 
 - (NSArray *)bundlesWithExtension:(NSString *)extension 
-													 inPath:(NSString *)path
+			   inPath:(NSString *)path
 {
   NSMutableArray *bundleList = [NSMutableArray array];
   NSEnumerator *enumerator;
@@ -263,39 +272,38 @@ static FSNodeRep *shared = nil;
   NSString *hdnFilePath = [path stringByAppendingPathComponent: @".hidden"];
   NSArray *hiddenNames = nil;  
 
-  if ([fm fileExistsAtPath: hdnFilePath]) {
-    NSString *str = [NSString stringWithContentsOfFile: hdnFilePath];
-	  hiddenNames = [str componentsSeparatedByString: @"\n"];
-	}
+  if ([fm fileExistsAtPath: hdnFilePath])
+    hiddenNames = [[NSString stringWithContentsOfFile: hdnFilePath] componentsSeparatedByString: @"\n"];
+ 
 
-  if (hiddenNames || hideSysFiles || [hiddenPaths count]) {
-    NSMutableArray *filteredNames = [NSMutableArray array];
-	  int i;
+  if (hiddenNames || hideSysFiles || [hiddenPaths count])
+    {
+      NSMutableArray *filteredNames = [NSMutableArray array];
+      int i;
 
-    for (i = 0; i < [fnames count]; i++) {
-      NSString *fname = [fnames objectAtIndex: i];
-      NSString *fpath = [path stringByAppendingPathComponent: fname];
-      BOOL hidden = NO;
+      for (i = 0; i < [fnames count]; i++)
+	{
+	  NSString *fname = [fnames objectAtIndex: i];
+	  NSString *fpath = [path stringByAppendingPathComponent: fname];
+	  BOOL hidden = NO;
     
-      if ([fname hasPrefix: @"."] && hideSysFiles) {
-        hidden = YES;  
-      }
+	  if ([fname hasPrefix: @"."] && hideSysFiles)
+	    hidden = YES;  
     
-      if (hiddenNames && [hiddenNames containsObject: fname]) {
-        hidden = YES;  
-      }
+	  if (hiddenNames && [hiddenNames containsObject: fname])
+	    hidden = YES;  
 
-      if ([hiddenPaths containsObject: fpath]) {
-        hidden = YES;  
-      }
+	  if ([hiddenPaths containsObject: fpath])
+	    hidden = YES;  
       
-      if (hidden == NO) {
-        [filteredNames addObject: fname];
-      }
-    }
+	  if (hidden == NO)
+	    {
+	      [filteredNames addObject: fname];
+	    }
+	}
   
-    return filteredNames;
-  }
+      return filteredNames;
+    }
   
   return fnames;
 }
@@ -378,7 +386,7 @@ static FSNodeRep *shared = nil;
     }
   } 
   
-	return defSortOrder;
+  return defSortOrder;
 }
 
 - (SEL)compareSelectorForDirectory:(NSString *)dirpath
@@ -699,139 +707,62 @@ static FSNodeRep *shared = nil;
 
 @implementation NSWorkspace (mounting)
 
-#if !defined(HAVE_GETMNTENT) || !defined(MNT_DIR)
-  #ifndef __APPLE__
-    static char mtabuf[1024] = "";
-  #endif
-#endif
-
 - (NSArray *)mountedVolumes
 {
   NSMutableArray *volumes = [NSMutableArray array];
-  
-#ifndef __APPLE__
-  #if defined(HAVE_GETMNTENT) && defined(MNT_DIR)
-    if ([[NSFileManager defaultManager] fileExistsAtPath: @"/etc/mtab"]) {
-      FILE *fp = fopen("/etc/mtab", "r");
-      struct mntent	*mnt;
 
-      while ((mnt = getmntent(fp)) != 0) { 
-        NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-
-        [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSNAME]
-                 forKey: @"name"]; 
-        [dict setObject: [NSString stringWithUTF8String: mnt->MNT_DIR]
-                 forKey: @"dir"];  
-        [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSTYPE]
-                 forKey: @"type"];  
-
-        [volumes addObject: dict];
-      }
-
-      fclose(fp);
-    
-    } else {
-      /* FIXME add something for Hurd */
-      
-    }       
-        
-  #else   // NO GETMNTENT
-    unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
-    NSString *mtab = nil;
-  
-    if (systype == NSGNULinuxOperatingSystem) {
-      NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-      NSString *mtabpath = [defaults stringForKey: @"GSMtabPath"];
-      
-      if (mtabpath == nil) {
-        mtabpath = @"/etc/mtab";
-      }
-
-      if ([[NSFileManager defaultManager] fileExistsAtPath: mtabpath]) {
-        mtab = [NSString stringWithContentsOfFile: mtabpath];
-      }
-
-    } else if (systype == NSBSDOperatingSystem) {
-      NSTask *task = [NSTask new]; 
-      NSPipe *pipe = [NSPipe pipe];
-      NSFileHandle *handle = [pipe fileHandleForReading];
-
-      [task setLaunchPath: @"mount"];
-      [task setArguments: [NSArray arrayWithObject: @"-p"]];
-      [task setStandardOutput: pipe];    
-
-      [task launch];
-      [task waitUntilExit];
-
-      if ([task terminationStatus] == 0) {
-        NSData *data = [handle readDataToEndOfFile];
-        unsigned len = [data length];
-
-        if (len) {
-          const char *bytes = [data bytes];
-          int i;
-
-          memset(mtabuf, '\0', 1024);
-
-          for (i = 0; i < len; i++) {
-            if (bytes[i] == '\t') {
-              mtabuf[i] = ' ';
-            } else {
-              mtabuf[i] = bytes[i]; 
-            } 
-          }
-
-          mtab = [NSString stringWithUTF8String: mtabuf];
-        }
-      }
-
-      RELEASE (task);     
-    }
-    
-    if (mtab) {
-      NSArray *lines = [mtab componentsSeparatedByString: @"\n"];
-      int i;
-      
-      for (i = 0; i < [lines count]; i++) {
-        NSString *line = [lines objectAtIndex: i];
-        
-        if ([line length]) {
-          NSArray	*parts = [line componentsSeparatedByString: @" "];
-
-          if ([parts count] == 6) {  
-            NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-
-            [dict setObject: [parts objectAtIndex: 0] forKey: @"name"]; 
-            [dict setObject: [parts objectAtIndex: 1] forKey: @"dir"]; 
-            [dict setObject: [parts objectAtIndex: 2] forKey: @"type"]; 
-                        
-            [volumes addObject: dict];
-          }
-        }
-      }
-    }
-    
-  #endif
-#else   // __APPLE__
+#ifdef HAVE_GETMNTINFO
+  /* most BSDs and derivatives inclusing Apple */
   struct statfs *buf;
   int i, count;
   
   count = getmntinfo(&buf, 0);
   
-	for (i = 0; i < count; i++) {
-    NSMutableDictionary *dict = [NSMutableDictionary dictionary];  
+  for (i = 0; i < count; i++)
+    {
+      NSMutableDictionary *dict = [NSMutableDictionary dictionary];  
   
-    [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntfromname]
-             forKey: @"name"]; 
-    [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntonname]
-             forKey: @"dir"]; 
-    [dict setObject: [NSString stringWithUTF8String: buf[i].f_fstypename]
-             forKey: @"type"]; 
+      [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntfromname]
+	       forKey: @"name"]; 
+      [dict setObject: [NSString stringWithUTF8String: buf[i].f_mntonname]
+	       forKey: @"dir"]; 
+      [dict setObject: [NSString stringWithUTF8String: buf[i].f_fstypename]
+	       forKey: @"type"]; 
 
-    [volumes addObject: dict];
-  }
-#endif
+      [volumes addObject: dict];
+    }
+#elif defined(HAVE_GETMNTENT) && defined(MNT_DIR)
+  /* most probably linux */
+  if ([[NSFileManager defaultManager] fileExistsAtPath: @"/etc/mtab"])
+    {
+      FILE *fp = fopen(MNTTAB, "r");
+      struct mntent	*mnt;
+
+      while ((mnt = getmntent(fp)) != NULL )
+	{ 
+	  NSMutableDictionary *dict = [NSMutableDictionary dictionary];
+
+	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSNAME]
+		   forKey: @"name"]; 
+	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_DIR]
+		   forKey: @"dir"];  
+	  [dict setObject: [NSString stringWithUTF8String: mnt->MNT_FSTYPE]
+		   forKey: @"type"];  
+
+	  [volumes addObject: dict];
+	}
+
+      fclose(fp);
     
+    }
+  else
+    {
+      /* FIXME add something for Hurd */
+      
+    }       
+#endif
+
+  NSLog(@"Volumes %@", volumes);   
   return volumes;
 }
 
@@ -885,40 +816,43 @@ static FSNodeRep *shared = nil;
   domain = [defaults persistentDomainForName: NSGlobalDomain];
   reserved = [domain objectForKey: @"GSReservedMountNames"];
   
-  if (reserved == nil) {
-    CREATE_AUTORELEASE_POOL(arp);
-    NSMutableDictionary *mdomain = [domain mutableCopy];  
-    unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
+  if (reserved == nil)
+    {
+      CREATE_AUTORELEASE_POOL(arp);
+      NSMutableDictionary *mdomain = [domain mutableCopy];  
+      unsigned int systype = [[NSProcessInfo processInfo] operatingSystem];
   
-    switch(systype) {
-      case NSGNULinuxOperatingSystem:
-        reserved = [NSArray arrayWithObjects: @"proc", @"devpts", @"shm", 
-                                                    @"usbdevfs", @"devpts", 
-                                                    @"sysfs", @"tmpfs", nil];
-        break;
+      switch(systype)
+	{
+	case NSGNULinuxOperatingSystem:
+	  reserved = [NSArray arrayWithObjects: @"proc", @"devpts", @"shm", 
+			      @"usbdevfs", @"devpts", 
+			      @"sysfs", @"tmpfs", @"procfs", nil];
+	  break;
 
-      case NSBSDOperatingSystem:
-        reserved = [NSArray arrayWithObjects: @"devfs", nil];
-        break;
+	case NSBSDOperatingSystem:
+	  reserved = [NSArray arrayWithObjects: @"devfs", @"procfs", nil];
+	  break;
 
-      case NSMACHOperatingSystem:
-        reserved = [NSArray arrayWithObjects: @"devfs", @"fdesc", 
-                                                    @"<volfs>", nil];
-        break;
+	case NSMACHOperatingSystem:
+	  reserved = [NSArray arrayWithObjects: @"devfs", @"fdesc", 
+			      @"<volfs>", nil];
+	  break;
     
-      default:
-        break;
+	default:
+	  break;
+	}
+    
+      if (reserved)
+	{
+	  [mdomain setObject: reserved forKey: @"GSReservedMountNames"];
+	  [defaults setPersistentDomain: mdomain forName: NSGlobalDomain];
+	  [defaults synchronize];
+	}
+    
+      RELEASE (mdomain);
+      RELEASE (arp);
     }
-    
-    if (reserved) {
-      [mdomain setObject: reserved forKey: @"GSReservedMountNames"];
-      [defaults setPersistentDomain: mdomain forName: NSGlobalDomain];
-      [defaults synchronize];
-    }
-    
-    RELEASE (mdomain);
-    RELEASE (arp);
-  }
 
   return reserved;
 }
@@ -977,13 +911,14 @@ static FSNodeRep *shared = nil;
   NSArray *reserved = [self reservedMountNames];
   unsigned i;
 
-  for (i = 0; i < [mounted count]; i++) {
-    NSDictionary *dict = [mounted objectAtIndex: i];
+  for (i = 0; i < [mounted count]; i++)
+    {
+      NSDictionary *dict = [mounted objectAtIndex: i];
 
-    if ([reserved containsObject: [dict objectForKey: @"name"]] == NO) {
-      [mpoints addObject: [dict objectForKey: @"dir"]];
+      if ([reserved containsObject: [dict objectForKey: @"name"]] == NO) {
+	[mpoints addObject: [dict objectForKey: @"dir"]];
+      }
     }
-  }
   
   return mpoints;
 }
