@@ -1,6 +1,6 @@
 /* mdextractor.m
  *  
- * Copyright (C) 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@dtedu.net>
  * Date: February 2006
@@ -22,14 +22,16 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <limits.h>
 #include <float.h>
-#include "mdextractor.h"
-#include "dbschema.h"
+
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+
+#import "mdextractor.h"
+#import "dbschema.h"
 #include "config.h"
 
 #define DLENGTH 256
@@ -830,7 +832,7 @@ static void time_stamp(sqlite3_context *context, int argc, sqlite3_value **argv)
     
     [sqlite executeQuery: @"COMMIT"];
     
-    GWDebugLog(path);
+    GWDebugLog(@"%@", path);
     
     fcount++;
 
@@ -902,7 +904,7 @@ static void time_stamp(sqlite3_context *context, int argc, sqlite3_value **argv)
                             filesCount: fcount
                            indexedDone: NO];
                            
-              GWDebugLog(@"updating %i", fcount);             
+              GWDebugLog(@"updating %lu", fcount);             
             }
           }
           
