@@ -1,8 +1,10 @@
 /* GWSpatialViewer.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola
+ *
  * Date: June 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -101,7 +103,7 @@
         RETAIN (rootViewerKey);
       }
       
-      prefsname = [NSString stringWithFormat: @"viewer_at_%@_%i", 
+      prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
                             [node path], [rootViewerKey unsignedLongValue]];
 
     } else {
@@ -708,7 +710,7 @@
       NSString *prefsname;
     
       if (rootViewerKey != nil) {
-        prefsname = [NSString stringWithFormat: @"viewer_at_%@_%i", 
+        prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
                             [baseNode path], [rootViewerKey unsignedLongValue]];
       } else {
         prefsname = [NSString stringWithFormat: @"viewer_at_%@", [baseNode path]];
@@ -1158,9 +1160,9 @@
     } else if ([itemTitle isEqual: NSLocalizedString(@"Background Color...", @"")]) {
       return [nodeView respondsToSelector: @selector(setBackgroundColor:)];
 
-    } else if (sel_eq(action, @selector(duplicateFiles:))
-                    || sel_eq(action, @selector(recycleFiles:))
-                        || sel_eq(action, @selector(deleteFiles:))) {
+    } else if (sel_isEqual(action, @selector(duplicateFiles:))
+                    || sel_isEqual(action, @selector(recycleFiles:))
+                        || sel_isEqual(action, @selector(deleteFiles:))) {
       if (lastSelection && [lastSelection count]
               && ([lastSelection isEqual: baseNodeArray] == NO)) {
         return ([[baseNode path] isEqual: [gworkspace trashPath]] == NO);
@@ -1168,7 +1170,7 @@
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openSelection:))) {
+    } else if (sel_isEqual(action, @selector(openSelection:))) {
       if ([[baseNode path] isEqual: [gworkspace trashPath]] == NO) {
         return (lastSelection && [lastSelection count] 
                 && ([lastSelection isEqual: baseNodeArray] == NO));
@@ -1176,14 +1178,14 @@
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openSelectionAsFolder:))) {
+    } else if (sel_isEqual(action, @selector(openSelectionAsFolder:))) {
       if (lastSelection && ([lastSelection count] == 1)) {  
-        return [[lastSelection objectAtIndex: 0] isPackage];
+        return [[lastSelection objectAtIndex: 0] isDirectory];
       }
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openWith:))) {
+    } else if (sel_isEqual(action, @selector(openWith:))) {
       BOOL canopen = YES;
       int i;
 
@@ -1204,8 +1206,8 @@
 
       return canopen;
 
-    } else if (sel_eq(action, @selector(newFolder:))
-                                || sel_eq(action, @selector(newFile:))) {
+    } else if (sel_isEqual(action, @selector(newFolder:))
+                                || sel_isEqual(action, @selector(newFile:))) {
       if ([[baseNode path] isEqual: [gworkspace trashPath]] == NO) {
         return [[nodeView shownNode] isWritable];
       }
@@ -1214,6 +1216,11 @@
     } 
     
     return YES;
+  } else {
+    SEL action = [menuItem action];
+    if (sel_isEqual(action, @selector(makeKeyAndOrderFront:))) {
+      return YES;
+    }
   }
   
   return NO;
