@@ -1,8 +1,9 @@
 /* GWViewer.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola
  * Date: July 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -115,7 +116,7 @@
         RETAIN (rootViewerKey);
       }
       
-      prefsname = [NSString stringWithFormat: @"viewer_at_%@_%i", 
+      prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
                             [node path], [rootViewerKey unsignedLongValue]];
 
     } else {
@@ -138,7 +139,7 @@
     
     if (viewerPrefs == nil) {
       defEntry = [defaults dictionaryForKey: prefsname];
-    
+      NSLog(@"prfsname %@", defEntry);
       if (defEntry) {
         viewerPrefs = [defEntry copy];
       } else {
@@ -147,7 +148,7 @@
     }
     
     viewType = [viewerPrefs objectForKey: @"viewtype"];
-    
+    NSLog(@"viewtype: %@", viewType);
     if (viewType == nil) {
       if (stype != nil) {
         viewType = stype;
@@ -164,7 +165,7 @@
     RETAIN (viewType);
     
     defEntry = [viewerPrefs objectForKey: @"shelfheight"];
-    
+    NSLog(@"height: %@", defEntry);
     if (defEntry) {
       shelfHeight = [defEntry floatValue];
     } else {
@@ -175,7 +176,7 @@
     [vwrwin setDelegate: self];
 
     defEntry = [viewerPrefs objectForKey: @"geometry"];
-    
+    NSLog(@"geometry: %@", defEntry);
     if (defEntry) {
       [vwrwin setFrameFromString: defEntry];
     } else {
@@ -879,7 +880,7 @@
       NSString *prefsname;
     
       if (rootViewerKey != nil) {
-        prefsname = [NSString stringWithFormat: @"viewer_at_%@_%i", 
+        prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
                             [baseNode path], [rootViewerKey unsignedLongValue]];
       } else {
         prefsname = [NSString stringWithFormat: @"viewer_at_%@", [baseNode path]];
@@ -1467,9 +1468,9 @@
     } else if ([itemTitle isEqual: NSLocalizedString(@"Background Color...", @"")]) {
       return [nodeView respondsToSelector: @selector(setBackgroundColor:)];
 
-    } else if (sel_eq(action, @selector(duplicateFiles:))
-                    || sel_eq(action, @selector(recycleFiles:))
-                        || sel_eq(action, @selector(deleteFiles:))) {
+    } else if (sel_isEqual(action, @selector(duplicateFiles:))
+                    || sel_isEqual(action, @selector(recycleFiles:))
+                        || sel_isEqual(action, @selector(deleteFiles:))) {
       if (lastSelection && [lastSelection count]
               && ([lastSelection isEqual: baseNodeArray] == NO)) {
         return ([[baseNode path] isEqual: [gworkspace trashPath]] == NO);
@@ -1477,7 +1478,7 @@
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openSelection:))) {
+    } else if (sel_isEqual(action, @selector(openSelection:))) {
       if ([[baseNode path] isEqual: [gworkspace trashPath]] == NO) {
         BOOL canopen = YES;
         int i;
@@ -1501,14 +1502,14 @@
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openSelectionAsFolder:))) {
+    } else if (sel_isEqual(action, @selector(openSelectionAsFolder:))) {
       if (lastSelection && ([lastSelection count] == 1)) {  
-        return [[lastSelection objectAtIndex: 0] isPackage];
+        return [[lastSelection objectAtIndex: 0] isDirectory];
       }
 
       return NO;
 
-    } else if (sel_eq(action, @selector(openWith:))) {
+    } else if (sel_isEqual(action, @selector(openWith:))) {
       BOOL canopen = YES;
       int i;
 
@@ -1529,8 +1530,8 @@
 
       return canopen;
 
-    } else if (sel_eq(action, @selector(newFolder:))
-                                  || sel_eq(action, @selector(newFile:))) {
+    } else if (sel_isEqual(action, @selector(newFolder:))
+                                  || sel_isEqual(action, @selector(newFile:))) {
       if ([[baseNode path] isEqual: [gworkspace trashPath]] == NO) {
         return [[nodeView shownNode] isWritable];
       }
@@ -1539,6 +1540,11 @@
     }
     
     return YES;   
+  } else {
+    SEL action = [menuItem action];
+    if (sel_isEqual(action, @selector(makeKeyAndOrderFront:))) {
+      return YES;
+    }
   }
   
   return NO;
