@@ -1,6 +1,6 @@
 /* GWViewerShelf.h
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -22,15 +22,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
 #include <math.h>
-#include "GWViewerShelf.h"
-#include "GWViewer.h"
-#include "GWorkspace.h"
-#include "FSNBrowser.h"
-#include "FSNIconsView.h"
-#include "FSNIcon.h"
-#include "FSNFunctions.h"
+
+#import <AppKit/AppKit.h>
+
+#import "GWViewerShelf.h"
+#import "GWViewer.h"
+#import "GWorkspace.h"
+#import "FSNBrowser.h"
+#import "FSNIconsView.h"
+#import "FSNIcon.h"
+#import "FSNFunctions.h"
 
 #define DEF_ICN_SIZE 48
 #define DEF_TEXT_SIZE 12
@@ -40,6 +42,27 @@
 #define Y_MARGIN (4)
 #define EDIT_MARGIN (4)
 
+@interface GWTextField : NSTextField
+@end
+
+@implementation GWTextField
+
+- (id) initWithFrame: (NSRect)aFrame
+{
+  NSTextFieldCell *cell;
+
+  self = [super initWithFrame: aFrame];
+
+  cell =  [[[FSNTextCell alloc] init] autorelease];
+  [cell setDrawsBackground: YES];
+
+  [self setCell: cell];
+
+  return self;
+}
+
+@end
+
 
 @implementation GWViewerShelf
 
@@ -151,7 +174,7 @@
 
 		watchedPaths = [[NSCountedSet alloc] initWithCapacity: 1];
 
-    focusedIconLabel = [NSTextField new];
+    focusedIconLabel = [GWTextField new];
 		[focusedIconLabel setFont: [NSFont systemFontOfSize: 12]];
 		[focusedIconLabel setBezeled: NO];
 		[focusedIconLabel setAlignment: NSCenterTextAlignment];
@@ -782,6 +805,11 @@
   return [NSArray arrayWithArray: selectedPaths];
 } 
 
+- (void)openSelectionInNewViewer:(BOOL)newv
+{
+  [viewer openSelectionInNewViewer: newv];
+}
+
 - (void)nodeContentsWillChange:(NSDictionary *)info
 {
   [self checkLockedReps];
