@@ -1,6 +1,6 @@
 /* GWViewerSplit.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -22,8 +22,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
-#include "GWViewerSplit.h"
+#import <AppKit/AppKit.h>
+#import "GWViewerSplit.h"
 
 @implementation GWViewerSplit 
 
