@@ -1,6 +1,6 @@
 /* LSFolder.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: October 2004
@@ -25,11 +25,13 @@
 #ifndef LS_FOLDER_H
 #define LS_FOLDER_H
 
-#include <Foundation/Foundation.h>
-#include "FSNodeRep.h"
+#import <Foundation/Foundation.h>
+#import "FSNodeRep.h"
 
 @class NSWindow;
 @class NSView;
+@class NSPopUpButton;
+@class NSButton;
 @class ResultsTableView;
 @class NSTableColumn;
 @class FSNPathComponentsViewer;
@@ -79,17 +81,17 @@
   NSFileManager *fm;
   NSNotificationCenter *nc;
   
-  IBOutlet id win;
+  IBOutlet NSWindow *win;
   BOOL forceclose;
 
   IBOutlet NSBox *topBox;
   IBOutlet NSBox *progBox; 
   ProgrView *progView;
-  IBOutlet id elementsLabel;
+  IBOutlet NSTextField *elementsLabel;
   NSString *elementsStr;
-  IBOutlet id editButt;
-  IBOutlet id autoupdatePopUp;
-  IBOutlet id updateButt;
+  IBOutlet NSButton *editButt;
+  IBOutlet NSPopUpButton *autoupdatePopUp;
+  IBOutlet NSButton *updateButt;
     
   IBOutlet NSScrollView *resultsScroll;
   ResultsTableView *resultsView;
@@ -186,7 +188,7 @@
 @interface ProgrView : NSView 
 {
   NSMutableArray *images;
-  int index;
+  unsigned index;
   float rfsh;
   NSTimer *progTimer;
   BOOL animating;
