@@ -1,8 +1,9 @@
 /* GWorkspace.m
  *  
- * Copyright (C) 2003-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola
  * Date: August 2001
  *
  * This file is part of the GNUstep GWorkspace application
@@ -287,9 +288,9 @@ static GWorkspace *gworkspace = nil;
   menuItem = addItemToMenu(mainMenu, @"Windows", @"", nil, @"");
   windows = AUTORELEASE ([NSMenu new]);
   [mainMenu setSubmenu: windows forItem: menuItem];		
-  addItemToMenu(windows, @"Arrange in Front", @"", nil, @"");
-  addItemToMenu(windows, @"Miniaturize Window", @"", nil, @"");
-  addItemToMenu(windows, @"Close Window", @"", @"closeMainWin:", @"w");
+  addItemToMenu(windows, @"Arrange in Front", @"", @"arrangeInFront:", @"");
+  addItemToMenu(windows, @"Miniaturize Window", @"", @"performMiniaturize:", @"m");
+  addItemToMenu(windows, @"Close Window", @"", @"performClose:", @"w");
 
 	// Services 
 	menuItem = addItemToMenu(mainMenu, @"Services", @"", nil, @"");
@@ -504,6 +505,16 @@ static GWorkspace *gworkspace = nil;
   NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
   NSNotificationCenter *dnc = [NSDistributedNotificationCenter defaultCenter];
   
+  NS_DURING
+    {
+      [NSApp setServicesProvider:self];
+    }
+  NS_HANDLER
+    {
+      NSLog(@"setServicesProvider: %@", localException);
+    }
+  NS_ENDHANDLER
+
   [nc addObserver: self 
          selector: @selector(fileSystemWillChange:) 
              name: @"GWFileSystemWillChangeNotification"
@@ -557,7 +568,7 @@ static GWorkspace *gworkspace = nil;
   [self resetSelectedPaths];
 }
 
-- (BOOL)applicationShouldTerminate:(NSApplication *)app 
+- (NSApplicationTerminateReply)applicationShouldTerminate:(NSApplication *)app 
 {
   NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
   
@@ -569,7 +580,7 @@ static GWorkspace *gworkspace = nil;
 					        NSLocalizedString(@"Ok", @""), 
                   nil, 
                   nil);  
-    return NO;  
+    return NSTerminateCancel;  
   }
     
   if ((dontWarnOnQuit == NO) && (loggingout == NO)) {
@@ -578,7 +589,7 @@ static GWorkspace *gworkspace = nil;
                       NSLocalizedString(@"No", @""),
                       NSLocalizedString(@"Yes", @""),
                       nil)) {
-      return NO;
+      return NSTerminateCancel;
     }
   }
 
@@ -593,11 +604,11 @@ static GWorkspace *gworkspace = nil;
   terminating = YES;
 
   [self updateDefaults];
-
-	TEST_CLOSE (prefController, [prefController myWin]);
-	TEST_CLOSE (fiend, [fiend myWin]);
-	TEST_CLOSE (history, [history myWin]); 
-	TEST_CLOSE (tshelfWin, tshelfWin);
+  
+  TEST_CLOSE (prefController, [prefController myWin]);
+  TEST_CLOSE (fiend, [fiend myWin]);
+  TEST_CLOSE (history, [history myWin]); 
+  TEST_CLOSE (tshelfWin, tshelfWin);
   TEST_CLOSE (startAppWin, [startAppWin win]);
 
   if (fswatcher) {
@@ -649,7 +660,7 @@ static GWorkspace *gworkspace = nil;
     }
   }
   		
-	return YES;
+  return NSTerminateNow;
 }
 
 - (NSString *)defEditor
@@ -1054,29 +1065,29 @@ static GWorkspace *gworkspace = nil;
 {	
   SEL action = [anItem action];
 
-  if (sel_eq(action, @selector(showRecycler:))) {
+  if (sel_isEqual(action, @selector(showRecycler:))) {
     return (([dtopManager isActive] == NO) || ([dtopManager dockActive] == NO));
   
-  } else if (sel_eq(action, @selector(emptyRecycler:))) {
+  } else if (sel_isEqual(action, @selector(emptyRecycler:))) {
     return ([trashContents count] != 0);
   
-  } else if (sel_eq(action, @selector(checkRemovableMedia:))) {  
+  } else if (sel_isEqual(action, @selector(checkRemovableMedia:))) {  
     return [dtopManager isActive];
   
-  } else if (sel_eq(action, @selector(removeTShelfTab:))
-              || sel_eq(action, @selector(renameTShelfTab:))
-                      || sel_eq(action, @selector(addTShelfTab:))) {
+  } else if (sel_isEqual(action, @selector(removeTShelfTab:))
+              || sel_isEqual(action, @selector(renameTShelfTab:))
+                      || sel_isEqual(action, @selector(addTShelfTab:))) {
     return [tshelfWin isVisible];
 
-  } else if (sel_eq(action, @selector(activateContextHelp:))) {
+  } else if (sel_isEqual(action, @selector(activateContextHelp:))) {
     return ([NSHelpManager isContextHelpModeActive] == NO);
 
-  } else if (sel_eq(action, @selector(logout:))) {
+  } else if (sel_isEqual(action, @selector(logout:))) {
     return !loggingout;
     
-  } else if (sel_eq(action, @selector(cut:))
-                || sel_eq(action, @selector(copy:))
-                  || sel_eq(action, @selector(paste:))) {
+  } else if (sel_isEqual(action, @selector(cut:))
+                || sel_isEqual(action, @selector(copy:))
+                  || sel_isEqual(action, @selector(paste:))) {
     NSWindow *kwin = [NSApp keyWindow];
 
     if (kwin && [kwin isKindOfClass: [TShelfWin class]]) {
@@ -1086,7 +1097,7 @@ static GWorkspace *gworkspace = nil;
         TShelfIconsView *iview = (TShelfIconsView *)[item view];
 
         if ([iview iconsType] == DATA_TAB) {
-          if (sel_eq(action, @selector(paste:))) {
+          if (sel_isEqual(action, @selector(paste:))) {
             return YES;
           } else {
             return [iview hasSelectedIcon];
@@ -1260,33 +1271,51 @@ static GWorkspace *gworkspace = nil;
 
 - (BOOL)openFile:(NSString *)fullPath
 {
-	NSString *appName = nil;
+  NSString *appName = nil;
   NSString *type = nil;
   BOOL success;
+  NSURL *aURL;
   
+  aURL = nil;
   [ws getInfoForFile: fullPath application: &appName type: &type];
   
-	if (appName == nil) {
-		appName = defEditor;
-	}		
+  if (appName == nil) {
+    appName = defEditor;
+  }
+
+  if (type == NSPlainFileType)
+    {
+      if ([[fullPath pathExtension] isEqualToString: @"webloc"])
+	{
+	  NSDictionary *weblocDict;
+	  NSString *urlString;
+
+	  weblocDict = [NSDictionary dictionaryWithContentsOfFile: fullPath];
+	  urlString = [weblocDict objectForKey:@"URL"];
+	  aURL = [NSURL URLWithString: urlString];
+        }
+    }	
   
   NS_DURING
     {
-  success = [ws openFile: fullPath withApplication: appName];
+      if (aURL == nil)
+	success = [ws openFile: fullPath withApplication: appName];
+      else
+	success = [ws openURL: aURL];
     }
   NS_HANDLER
     {
-  NSRunAlertPanel(NSLocalizedString(@"error", @""), 
-      [NSString stringWithFormat: @"%@ %@!", 
-          NSLocalizedString(@"Can't open ", @""), [fullPath lastPathComponent]],
-                                    NSLocalizedString(@"OK", @""), 
-                                    nil, 
-                                    nil);                                     
-  success = NO;
+      NSRunAlertPanel(NSLocalizedString(@"error", @""), 
+		      [NSString stringWithFormat: @"%@ %@!", 
+				NSLocalizedString(@"Can't open ", @""), [fullPath lastPathComponent]],
+		      NSLocalizedString(@"OK", @""), 
+		      nil, 
+		      nil);                                     
+      success = NO;
     }
   NS_ENDHANDLER  
   
-  return success;  
+    return success;  
 }
 
 - (BOOL)application:(NSApplication *)theApplication 
@@ -1910,55 +1939,67 @@ static GWorkspace *gworkspace = nil;
 
 - (void)connectDDBd
 {
-  if (ddbd == nil) {
-    ddbd = [NSConnection rootProxyForConnectionWithRegisteredName: @"ddbd" 
-                                                             host: @""];
+  if (ddbd == nil)
+    {
+      ddbd = [NSConnection rootProxyForConnectionWithRegisteredName: @"ddbd" 
+							       host: @""];
 
-    if (ddbd == nil) {
-	    NSString *cmd;
-      int i;
+      if (ddbd == nil)
+	{
+	  NSString *cmd;
+	  NSMutableArray *arguments;
+	  int i;
     
-      cmd = [NSTask launchPathForTool: @"ddbd"];    
+	  cmd = [NSTask launchPathForTool: @"ddbd"];    
                 
-      [startAppWin showWindowWithTitle: @"GWorkspace"
-                               appName: @"ddbd"
-                             operation: NSLocalizedString(@"starting:", @"")
-                          maxProgValue: 40.0];
-    
-      [NSTask launchedTaskWithLaunchPath: cmd arguments: nil];
+	  [startAppWin showWindowWithTitle: @"GWorkspace"
+				   appName: @"ddbd"
+				 operation: NSLocalizedString(@"starting:", @"")
+			      maxProgValue: 40.0];
+ 
+	  arguments = [NSMutableArray arrayWithCapacity:2];
+	  [arguments addObject:@"--daemon"];
+	  [arguments addObject:@"--auto"];  
+	  [NSTask launchedTaskWithLaunchPath: cmd arguments: arguments];
+
    
-      for (i = 1; i <= 40; i++) {
-        [startAppWin updateProgressBy: 1.0];
+	  for (i = 1; i <= 40; i++)
+	    {
+	      [startAppWin updateProgressBy: 1.0];
 	      [[NSRunLoop currentRunLoop] runUntilDate:
-		                     [NSDate dateWithTimeIntervalSinceNow: 0.1]];
+					    [NSDate dateWithTimeIntervalSinceNow: 0.1]];
 
-        ddbd = [NSConnection rootProxyForConnectionWithRegisteredName: @"ddbd" 
-                                                                 host: @""];                  
-        if (ddbd) {
-          [startAppWin updateProgressBy: 40.0 - i];
-          break;
-        }
-      }
+	      ddbd = [NSConnection rootProxyForConnectionWithRegisteredName: @"ddbd" 
+								       host: @""];                  
+	      if (ddbd)
+		{
+		  [startAppWin updateProgressBy: 40.0 - i];
+		  break;
+		}
+	    }
 
-      [[startAppWin win] close];
-    }
+	  [[startAppWin win] close];
+	}
     
-    if (ddbd) {
-      RETAIN (ddbd);
-      [ddbd setProtocolForProxy: @protocol(DDBdProtocol)];
+      if (ddbd)
+	{
+	  RETAIN (ddbd);
+	  [ddbd setProtocolForProxy: @protocol(DDBdProtocol)];
     
-	    [[NSNotificationCenter defaultCenter] addObserver: self
-	                   selector: @selector(ddbdConnectionDidDie:)
-		                     name: NSConnectionDidDieNotification
-		                   object: [ddbd connectionForProxy]];
-    } else {
-      NSRunAlertPanel(nil,
-              NSLocalizedString(@"unable to contact ddbd.", @""),
-              NSLocalizedString(@"Ok", @""),
-              nil, 
-              nil);  
+	  [[NSNotificationCenter defaultCenter] addObserver: self
+						   selector: @selector(ddbdConnectionDidDie:)
+						       name: NSConnectionDidDieNotification
+						     object: [ddbd connectionForProxy]];
+	}
+      else
+	{
+	  NSRunAlertPanel(nil,
+			  NSLocalizedString(@"unable to contact ddbd.", @""),
+			  NSLocalizedString(@"Ok", @""),
+			  nil, 
+			  nil);  
+	}
     }
-  }
 }  
   
 - (void)ddbdConnectionDidDie:(NSNotification *)notif
@@ -2139,13 +2180,26 @@ static GWorkspace *gworkspace = nil;
 }
 
 //
-// Menu Operations
+// Workspace service
 //
-- (void)closeMainWin:(id)sender
+
+- (void)openInWorkspace:(NSPasteboard *)pboard
+	       userData:(NSString *)userData
+		  error:(NSString **)error
 {
-  [[NSApp keyWindow] performClose: sender];
+  NSArray *types = [pboard types];
+  if ([types containsObject: NSStringPboardType])
+    {
+      NSString *path = [pboard stringForType: NSStringPboardType];
+      path = [path stringByTrimmingCharactersInSet:
+		     [NSCharacterSet whitespaceAndNewlineCharacterSet]];
+      [self openSelectedPaths: [NSArray arrayWithObject: path] newViewer: YES];
+    }
 }
 
+//
+// Menu Operations
+//
 - (void)logout:(id)sender
 {
   [self startLogout];
@@ -2617,14 +2671,17 @@ static GWorkspace *gworkspace = nil;
 
 - (void)performFileOperation:(NSDictionary *)opinfo
 {
-	NSString *operation = [opinfo objectForKey: @"operation"];
-	NSString *source = [opinfo objectForKey: @"source"];
-	NSString *destination = [opinfo objectForKey: @"destination"];
-	NSArray *files = [opinfo objectForKey: @"files"];
-	int tag;
-	
-	[self performFileOperation: operation source: source 
-											destination: destination files: files tag: &tag];
+  NSString *operation = [opinfo objectForKey: @"operation"];
+  NSString *source = [opinfo objectForKey: @"source"];
+  NSString *destination = [opinfo objectForKey: @"destination"];
+  NSArray *files = [opinfo objectForKey: @"files"];
+  int tag;
+
+  if (destination == nil && [operation isEqualToString:@"NSWorkspaceRecycleOperation"])
+    destination = [self trashPath];
+
+  [self performFileOperation: operation source: source 
+		 destination: destination files: files tag: &tag];
 }
 
 - (BOOL)filenamesWasCutted
@@ -2650,7 +2707,7 @@ static GWorkspace *gworkspace = nil;
   NSArray *srcPaths = [infoDict objectForKey: @"paths"];
   BOOL bookmark = [[infoDict objectForKey: @"bookmark"] boolValue];
   NSString *connName = [infoDict objectForKey: @"dndconn"];
-	NSArray *locContents = [fm directoryContentsAtPath: localPath];
+  NSArray *locContents = [fm directoryContentsAtPath: localPath];
   BOOL samename = NO;
   int i;
 
