@@ -1,6 +1,6 @@
 /* DesktopPref.m
  *  
- * Copyright (C) 2005 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -22,14 +22,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include "DesktopPref.h"
-#include "GWDesktopManager.h"
-#include "GWorkspace.h"
-#include "GWDesktopView.h"
-#include "Dock.h"
-#include "TShelf/TShelfWin.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import "DesktopPref.h"
+#import "GWDesktopManager.h"
+#import "GWorkspace.h"
+#import "GWDesktopView.h"
+#import "Dock.h"
+#import "TShelf/TShelfWin.h"
 
 static NSString *nibName = @"DesktopPref";
 
@@ -37,9 +37,9 @@ static NSString *nibName = @"DesktopPref";
 
 - (void)dealloc
 {
-  TEST_RELEASE (prefbox);
-  TEST_RELEASE (imagePath);
-  TEST_RELEASE (imagesDir);
+  RELEASE (prefbox);
+  RELEASE (imagePath);
+  RELEASE (imagesDir);
 
   [super dealloc];
 }
@@ -53,10 +53,12 @@ static NSString *nibName = @"DesktopPref";
     if ([NSBundle loadNibNamed: nibName owner: self] == NO)
     {
       NSLog(@"failed to load %@!", nibName);
-    } else
+    }
+    else
     {
       NSString *impath;
       DockPosition dockpos;
+      DockStyle dockstyle;
       id cell;
       NSRect r;
 
@@ -67,19 +69,11 @@ static NSString *nibName = @"DesktopPref";
       gworkspace = [GWorkspace gworkspace];
 
       // Color
-      r = [[currColorBox contentView] bounds];
-      colorView = [[ColorView alloc] initWithFrame: r];
-      [colorView setColor: [[manager desktopView] currentColor]]; 
-      [currColorBox setContentView: colorView];
-      RELEASE (colorView);
-
       [NSColorPanel setPickerMask: NSColorPanelWheelModeMask 
                                   | NSColorPanelRGBModeMask 
                                   | NSColorPanelColorListModeMask];
       [NSColorPanel setPickerMode: NSWheelModeColorPanel];
-      panel = [NSColorPanel sharedColorPanel];
-      [panel setTarget: self];
-      [panel setContinuous: YES];
+      [colorWell setColor: [[manager desktopView] currentColor]];
 
       // Background image  
       [imageView setEditable: NO];
@@ -105,34 +99,37 @@ static NSString *nibName = @"DesktopPref";
       
       [imagePosMatrix selectCellAtRow: [[manager desktopView] backImageStyle] column: 0];
       
-      [useImageSwitch setState: [[manager desktopView] useBackImage] ? NSOnState : NSOffState];
+      BOOL useImage = [[manager desktopView] useBackImage];
+      [imageView setEnabled: useImage];
+      [chooseImageButt setEnabled: useImage];
+      [imagePosMatrix setEnabled: useImage];
+      [useImageSwitch setState: useImage ? NSOnState : NSOffState];
 
       // General
       [omnipresentCheck setState: ([manager usesXBundle] ? NSOnState : NSOffState)];
       [useDockCheck setState: ([manager dockActive] ? NSOnState : NSOffState)];
       dockpos = [manager dockPosition];
-      [dockPosMatrix selectCellAtRow: 0 column: dockpos];
+      [dockPosMatrix selectCellAtRow: dockpos column: 0];
+      dockstyle = [[manager dock] style];
+      [dockStyleMatrix selectCellAtRow: dockstyle column: 0];
       [hideTShelfCheck setState: (([[gworkspace tabbedShelf] autohide]) ? NSOnState : NSOffState)];
-
+  
+  
 
       /* Internationalization */
-      [[tabView tabViewItemAtIndex: 0] setLabel: NSLocalizedString(@"Back Color", @"")];
-      [[tabView tabViewItemAtIndex: 1] setLabel: NSLocalizedString(@"Back Image", @"")];
-      [[tabView tabViewItemAtIndex: 2] setLabel: NSLocalizedString(@"General", @"")];
+      [[tabView tabViewItemAtIndex: 0] setLabel: NSLocalizedString(@"Background", @"")];
+      [[tabView tabViewItemAtIndex: 1] setLabel: NSLocalizedString(@"General", @"")];
 
-      [currColorBox setTitle: NSLocalizedString(@"Current color", @"")];      
-      [chooseColorButt setTitle: NSLocalizedString(@"Choose", @"")];      
-      [setColorButt setTitle: NSLocalizedString(@"Set", @"")];    
-      
       cell = [imagePosMatrix cellAtRow: BackImageCenterStyle column: 0];
       [cell setTitle: NSLocalizedString(@"center", @"")];
       cell = [imagePosMatrix cellAtRow: BackImageFitStyle column: 0];
       [cell setTitle: NSLocalizedString(@"fit", @"")];
       cell = [imagePosMatrix cellAtRow: BackImageTileStyle column: 0];
       [cell setTitle: NSLocalizedString(@"tile", @"")];
+      cell = [imagePosMatrix cellAtRow: BackImageScaleStyle column: 0];
+      [cell setTitle: NSLocalizedString(@"scale", @"")];
       [useImageSwitch setTitle: NSLocalizedString(@"Use image", @"")];  
       [chooseImageButt setTitle: NSLocalizedString(@"Choose", @"")]; 
-      [setImageButt setTitle: NSLocalizedString(@"Set", @"")]; 
 
       [useDockCheck setTitle: NSLocalizedString(@"Show Dock", @"")];
       [dockPosLabel setStringValue: NSLocalizedString(@"Dock position:", @"")];
@@ -140,7 +137,11 @@ static NSString *nibName = @"DesktopPref";
       [cell setTitle: NSLocalizedString(@"Left", @"")];
       cell = [dockPosMatrix cellAtRow: 0 column: 1];
       [cell setTitle: NSLocalizedString(@"Right", @"")];
-   
+      [dockStyleLabel setStringValue: NSLocalizedString(@"Dock style:", @"")];
+      cell = [dockStyleMatrix cellAtRow: 0 column: 0];
+      [cell setTitle: NSLocalizedString(@"Classic", @"")];
+      cell = [dockStyleMatrix cellAtRow: 0 column: 1];
+      [cell setTitle: NSLocalizedString(@"Modern", @"")];
       [hideTShelfCheck setTitle: NSLocalizedString(@"Autohide Tabbed Shelf", @"")];
     }
   }
@@ -159,22 +160,10 @@ static NSString *nibName = @"DesktopPref";
 }
 
 // Color
-- (IBAction)chooseColor:(id)sender
-{
-  [panel setAction: @selector(colorChoosen:)];
-  [panel setColor: [colorView color]];
-  [NSApp orderFrontColorPanel: nil];
-}
-
-- (void)colorChoosen:(id)sender
-{
-  [colorView setColor: [[sender color] colorUsingColorSpaceName: NSCalibratedRGBColorSpace]];      
-  [colorView setNeedsDisplay: YES];
-}
 
 - (IBAction)setColor:(id)sender
 {
-  [[manager desktopView] setCurrentColor: [colorView color]];
+  [[manager desktopView] setCurrentColor: [colorWell color]];
   [gworkspace tshelfBackgroundDidChange];
 }
 
@@ -182,11 +171,11 @@ static NSString *nibName = @"DesktopPref";
 // Background image
 - (IBAction)chooseImage:(id)sender
 {
-	NSOpenPanel *openPanel;
-	int result;
+  NSOpenPanel *openPanel;
+  int result;
    
-	openPanel = [NSOpenPanel openPanel];
-	[openPanel setTitle: NSLocalizedString(@"Choose Image", @"")];	
+  openPanel = [NSOpenPanel openPanel];
+  [openPanel setTitle: NSLocalizedString(@"Choose Image", @"")];	
   [openPanel setAllowsMultipleSelection: NO];
   [openPanel setCanChooseFiles: YES];
   [openPanel setCanChooseDirectories: NO];
@@ -213,10 +202,7 @@ static NSString *nibName = @"DesktopPref";
     
     RELEASE (pool);
   }
-}
 
-- (IBAction)setImage:(id)sender
-{
   if (imagePath) {  
     [[manager desktopView] setBackImageAtPath: imagePath];
     [imagePosMatrix selectCellAtRow: [[manager desktopView] backImageStyle] 
@@ -225,6 +211,11 @@ static NSString *nibName = @"DesktopPref";
   }
 }
 
+- (IBAction)setImage:(id)sender
+{
+  // FIXME: Handle image dropped on image view?
+}
+
 - (IBAction)setImageStyle:(id)sender
 {
   id cell = [imagePosMatrix selectedCell];
@@ -237,8 +228,12 @@ static NSString *nibName = @"DesktopPref";
 
 - (IBAction)setUseImage:(id)sender
 {
-  [[manager desktopView] setUseBackImage: ([sender state] == NSOnState) ? YES : NO];
+  BOOL useImage = ([sender state] == NSOnState);
+  [[manager desktopView] setUseBackImage: useImage];
   [gworkspace tshelfBackgroundDidChange];
+  [imageView setEnabled: useImage];
+  [chooseImageButt setEnabled: useImage];
+  [imagePosMatrix setEnabled: useImage];
 }
 
 
@@ -262,44 +257,20 @@ static NSString *nibName = @"DesktopPref";
   int row, col;
   
   [dockPosMatrix getRow: &row column: &col ofCell: cell];
-  [manager setDockPosition: (col == 0) ? DockPositionLeft : DockPositionRight];
+  [manager setDockPosition: (row == 0) ? DockPositionLeft : DockPositionRight];
 }
 
+- (IBAction)setDockStyle:(id)sender
+{
+  id cell = [dockStyleMatrix selectedCell];
+  int row, col;
+  
+  [dockStyleMatrix getRow: &row column: &col ofCell: cell];
+  [[manager dock] setStyle: (row == 0) ? DockStyleClassic : DockStyleModern];
+}
 - (IBAction)setTShelfAutohide:(id)sender
 {
   [[gworkspace tabbedShelf] setAutohide: ([sender state] == NSOnState)];
 }
 
 @end
-
-
-@implementation ColorView
-
-- (void)dealloc
-{
-  TEST_RELEASE (color);
-  [super dealloc];
-}
-
-- (void)setColor:(NSColor *)c
-{
-  ASSIGN (color, c);
-}
-
-- (NSColor *)color
-{
-  return color;
-}
-
-- (void)drawRect:(NSRect)rect
-{
-  [super drawRect: rect];
-  
-  if (color) {
-    [color set];
-    NSRectFill(rect);
-  } 
-}
-
-@end
-
