@@ -1,6 +1,6 @@
 /* WorkspaceApplication.m
  *  
- * Copyright (C) 2006-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2006
@@ -28,16 +28,16 @@
 #import <AppKit/AppKit.h>
 #import <GNUstepBase/GNUstep.h>
 
-#include "GWorkspace.h"
-#include "GWFunctions.h"
-#include "FSNodeRep.h"
-#include "FSNFunctions.h"
-#include "GWorkspace.h"
-#include "GWDesktopManager.h"
-#include "Dock.h"
-#include "GWViewersManager.h"
-#include "Operation.h"
-#include "StartAppWin.h"
+#import "GWorkspace.h"
+#import "GWFunctions.h"
+#import "FSNodeRep.h"
+#import "FSNFunctions.h"
+#import "GWorkspace.h"
+#import "GWDesktopManager.h"
+#import "Dock.h"
+#import "GWViewersManager.h"
+#import "Operation.h"
+#import "StartAppWin.h"
 
 @implementation GWorkspace (WorkspaceApplication)
 
@@ -47,27 +47,43 @@
                        files:(NSArray *)files 
                          tag:(int *)tag
 {
-  if (loggingout == NO) {
-    NSMutableDictionary *opdict = [NSMutableDictionary dictionary];
+  if (loggingout == NO)
+    {
+      NSMutableDictionary *opdict = [NSMutableDictionary dictionary];
 
-    [opdict setObject: operation forKey: @"operation"];
-    [opdict setObject: source forKey: @"source"];
-    [opdict setObject: destination forKey: @"destination"];
-    [opdict setObject: files forKey: @"files"];
+      if (operation != nil)
+	[opdict setObject: operation forKey: @"operation"];
+      else
+	NSLog(@"performFileOperation: operation can't be nil");
+ 
+      if (operation != nil)
+	[opdict setObject: source forKey: @"source"];
+      else
+	NSLog(@"performFileOperation: source is nil");
 
-    [fileOpsManager performOperation: opdict];
+      if (destination == nil && [operation isEqualToString:@"NSWorkspaceRecycleOperation"])
+	destination = [self trashPath];
+      if (destination != nil)
+	[opdict setObject: destination forKey: @"destination"];
 
-    *tag = 0;
+      if (files != nil)
+	[opdict setObject: files forKey: @"files"];
+
+      [fileOpsManager performOperation: opdict];
+
+      *tag = 0;
     
-    return YES;
+      return YES;
   
-  } else {
-    NSRunAlertPanel(nil, 
-                  NSLocalizedString(@"GWorkspace is logging out!", @""),
-					        NSLocalizedString(@"Ok", @""), 
-                  nil, 
-                  nil);  
-  }
+    }
+  else
+    {
+      NSRunAlertPanel(nil, 
+		      NSLocalizedString(@"GWorkspace is logging out!", @""),
+		      NSLocalizedString(@"Ok", @""), 
+		      nil, 
+		      nil);  
+    }
   
   return NO;
 }
@@ -1054,7 +1070,7 @@
   return self;
 }
 
-- (unsigned)hash
+- (NSUInteger)hash
 {
   return ([name hash] | [path hash]);
 }
